==> ant-design-vue-3.1.0-rc.1.tgz: package/es/dropdown/props.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { tuple } from '../_util/type';
import PropTypes from '../_util/vue-types';
import buttonTypes from '../button/buttonTypes';

var dropdownProps = function dropdownProps() {
  return {
    arrow: {
      type: [Boolean, Object],
      default: undefined
    },
    trigger: {
      type: [Array, String]
    },
    overlay: PropTypes.any,
    visible: PropTypes.looseBool,
    disabled: PropTypes.looseBool,
    align: {
      type: Object
    },
    getPopupContainer: PropTypes.func,
    prefixCls: PropTypes.string,
    transitionName: PropTypes.string,
    placement: PropTypes.oneOf(tuple('topLeft', 'topCenter', 'top', 'topRight', 'bottomLeft', 'bottomCenter', 'bottom', 'bottomRight')),
    overlayClassName: PropTypes.string,
    overlayStyle: PropTypes.style,
    forceRender: PropTypes.looseBool,
    mouseEnterDelay: PropTypes.number,
    mouseLeaveDelay: PropTypes.number,
    openClassName: PropTypes.string,
    minOverlayWidthMatchTrigger: PropTypes.looseBool,
    destroyPopupOnHide: PropTypes.looseBool,
    onVisibleChange: {
      type: Function
    },
    'onUpdate:visible': {
      type: Function
    }
  };
};

var buttonTypesProps = buttonTypes();

var dropdownButtonProps = function dropdownButtonProps() {
  return _extends(_extends({}, dropdownProps()), {
    type: buttonTypesProps.type,
    size: PropTypes.oneOf(tuple('small', 'large')),
    htmlType: buttonTypesProps.htmlType,
    href: PropTypes.string,
    disabled: PropTypes.looseBool,
    prefixCls: PropTypes.string,
    icon: PropTypes.any,
    title: PropTypes.string,
    loading: buttonTypesProps.loading,
    onClick: {
      type: Function
    }
  });
};

export { dropdownProps, dropdownButtonProps };
export default dropdownProps;

==> ant-design-vue-3.2.6.tgz: package/es/dropdown/props.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from '../_util/vue-types';
import buttonTypes from '../button/buttonTypes';

var dropdownProps = function dropdownProps() {
  return {
    arrow: {
      type: [Boolean, Object],
      default: undefined
    },
    trigger: {
      type: [Array, String]
    },
    overlay: PropTypes.any,
    visible: {
      type: Boolean,
      default: undefined
    },
    disabled: {
      type: Boolean,
      default: undefined
    },
    align: {
      type: Object
    },
    getPopupContainer: Function,
    prefixCls: String,
    transitionName: String,
    placement: String,
    overlayClassName: String,
    overlayStyle: {
      type: Object,
      default: undefined
    },
    forceRender: {
      type: Boolean,
      default: undefined
    },
    mouseEnterDelay: Number,
    mouseLeaveDelay: Number,
    openClassName: String,
    minOverlayWidthMatchTrigger: {
      type: Boolean,
      default: undefined
    },
    destroyPopupOnHide: {
      type: Boolean,
      default: undefined
    },
    onVisibleChange: {
      type: Function
    },
    'onUpdate:visible': {
      type: Function
    }
  };
};

var buttonTypesProps = buttonTypes();

var dropdownButtonProps = function dropdownButtonProps() {
  return _extends(_extends({}, dropdownProps()), {
    type: buttonTypesProps.type,
    size: String,
    htmlType: buttonTypesProps.htmlType,
    href: String,
    disabled: {
      type: Boolean,
      default: undefined
    },
    prefixCls: String,
    icon: PropTypes.any,
    title: String,
    loading: buttonTypesProps.loading,
    onClick: {
      type: Function
    }
  });
};

export { dropdownProps, dropdownButtonProps };
export default dropdownProps;
